==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Diverkañ ar stadegoù', # MODIF

	// I
	'icone_evolution_visites' => 'Emdroadur ar gweladennoù : <br />@visites@ gweladenn',
	'icone_repartition_actuelle' => 'Diskouez an dasparzh er mare-mañ',
	'icone_repartition_visites' => 'Dasparzh ar gweladennoù',
	'icone_statistiques_visites' => 'Stadegoù',
	'info_affichier_visites_articles_plus_visites' => 'Diskouez ar gweladennoù evit <b>ar pennadoù lennet ar muiañ, abaoe an deroù :</b>',
	'info_comment_lire_tableau' => 'Penaos lenn an daolenn-mañ',
	'info_forum_statistiques' => 'Stadegoù gweladenniñ',
	'info_popularite_2' => 'brud al lec’hienn :',
	'info_popularite_3' => 'brud; : @popularite@ ; gweladennoù : @visites@',
	'info_popularite_5' => 'brud; :',
	'info_question_vignettes_referer' => 'En ur sellet ouzh ar stadegoù e c’hallit teuler un tamm sell ouzh lec’hiennoù orin ar weladennerien',
	'info_question_vignettes_referer_oui' => 'Diskouez skeudennoùigoù lec’hiennoù orin ar weladennerien',
	'info_visites' => 'gweladenn :',
	'info_visites_plus_populaires' => 'Diskouez ar gweladennoù evit <b>ar pennadoù brudetañ</b> hag evit <b>ar pennadoù nevez-embannet :</b>',
	'info_zoom' => 'zoum',
	'item_gerer_statistiques' => 'Merañ ar stadegoù', # MODIF

	// O
	'onglet_origine_visites' => 'Orin ar gweladennoù',
	'onglet_repartition_debut' => 'abaoe an deroù',
	'onglet_repartition_lang' => 'Dasparzh diouzh ar yezh',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Diverket e vo an holl roadoù a denn da stadegoù gweladenniñ al lec’hienn, en o zouez ar re a heuilh berzh ar pennadoù.',
	'texte_comment_lire_tableau' => 'Renk ar pennad, hervez e vrud, a c’haller gwelet er marz; brud ar pennad (o rakwelet pet gweladenn en do bemdez ma kendalc’h ar gweladenniñ d’ar memes lusk) hag an niver a weladennoù abaoe an deroù a c’heller gwelet er lagadenn a zeu war wel pa dremen al logodenn war an titl.',
	'texte_signification' => 'Diskouez a ra ar barrennoù teñval sammad ar gweladennoù bodet (hollad an isrubrikennoù), hag ar barrennoù sklaer an niver a weladennoù evit pep rubrikenn.',
	'titre_evolution_visite' => 'Emdroadur ar gweladennoù',
	'titre_liens_entrants' => 'Liammoù davet al lec’hienn',
	'titre_page_statistiques' => 'Stadegoù dre rubrikennoù',
	'titre_page_statistiques_visites' => 'Stadegoù gweladenniñ'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Diverkañ ar stadegoù', # MODIF

	// I
	'icone_evolution_visites' => 'Emdroadur ar gweladennoù : <br />@visites@ gweladenn',
	'icone_repartition_actuelle' => 'Diskouez an dasparzh er mare-mañ',
	'icone_repartition_visites' => 'Dasparzh ar gweladennoù',
	'icone_statistiques_visites' => 'Stadegoù',
	'info_affichier_visites_articles_plus_visites' => 'Diskouez ar gweladennoù evit <b>ar pennadoù lennet ar muiañ, abaoe an deroù :</b>',
	'info_comment_lire_tableau' => 'Penaos lenn an daolenn-mañ',
	'info_forum_statistiques' => 'Stadegoù gweladenniñ',
	'info_popularite_2' => 'brud al lec’hienn :',
	'info_popularite_3' => 'brud; : @popularite@ ; gweladennoù : @visites@',
	'info_popularite_5' => 'brud; :',
	'info_question_vignettes_referer' => 'En ur sellet ouzh ar stadegoù e c’hallit teuler un tamm sell ouzh lec’hiennoù orin ar weladennerien', # MODIF
	'info_question_vignettes_referer_oui' => 'Diskouez skeudennoùigoù lec’hiennoù orin ar weladennerien',
	'info_visites' => 'gweladennoù :',
	'info_visites_plus_populaires' => 'Diskouez ar gweladennoù evit <b>ar pennadoù brudetañ</b> hag evit <b>ar pennadoù nevez-embannet :</b>',
	'info_zoom' => 'zoum',
	'item_gerer_statistiques' => 'Merañ ar stadegoù', # MODIF

	// O
	'onglet_origine_visites' => 'Orin ar gweladennoù',
	'onglet_repartition_debut' => 'abaoe an deroù',
	'onglet_repartition_lang' => 'Dasparzh diouzh ar yezh',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Diverket e vo an holl roadoù a denn da stadegoù gweladenniñ al lec’hienn, en o zouez ar re a heuilh berzh ar pennadoù.',
	'texte_comment_lire_tableau' => 'Renk ar pennad, hervez e vrud, a c’haller gwelet er marz; brud ar pennad (o rakwelet pet gweladenn en do bemdez ma kendalc’h ar gweladenniñ d’ar memes lusk) hag an niver a weladennoù abaoe an deroù a c’heller gwelet er lagadenn a zeu war wel pa dremen al logodenn war an titl.',
	'texte_signification' => 'Diskouez a ra ar barrennoù teñval sammad ar gweladennoù bodet (hollad an isrubrikennoù), hag ar barrennoù sklaer an niver a weladennoù evit pep rubrikenn.',
	'titre_evolution_visite' => 'Emdroadur ar gweladennoù',
	'titre_liens_entrants' => 'Liammoù davet al lec’hienn',
	'titre_page_statistiques' => 'Stadegoù dre rubrikennoù',
	'titre_page_statistiques_visites' => 'Stadegoù gweladenniñ'
);
